from Screens.Screen import Screen
from Screens.MovieSelection import MovieContextMenu, MovieSelection
from Components.ActionMap import ActionMap
from Components.Sources.List import List
from Components.Sources.StaticText import StaticText
from Components.config import config
from enigma import eServiceReference, eServiceCenter, iServiceInformation
from os import path as os_path
from Components.Merlin import MerlinImage
from MerlinMovieHistorySetup import MerlinMovieHistorySetup
from merlin.emerlin import eMerlin


class MerlinMovieHistoryList(List):

	def __init__(self, list):
		List.__init__(self, list = list, enableWrapAround=True, item_height=28, buildfunc=self.buildListEntry)

	def buildListEntry(self, filename):
		service = eServiceReference(filename)
		serviceHandler = eServiceCenter.getInstance()
		info = serviceHandler.info(service)
		description = ""
		extension = filename.split('.')[-1].lower()
		check = 1
		if extension in MerlinImage.getExtensions():
			metaData = eMerlin.getInstance().parseMeta(service.getPath())
			if metaData:
				check = 0
				description = metaData.getDescription()
				name = metaData.getName()
			else:
				event = eMerlin.getInstance().getEvent(service)
				if event:
					check = 0
					description = event.getShortDescription()
					name = event.getEventName()
		if check:
			name = info.getName(service)
			description = info.getInfoString(service, iServiceInformation.sDescription)
		
		if description:
			name = name + " - " + description
		
		return (name, os_path.dirname(service.getPath()) + "/")


class MerlinMovieHistoryScreen(Screen):

	def __init__(self, session, current_dialog):
		Screen.__init__(self, session)
		self.session = session
		if isinstance(current_dialog,MovieContextMenu):
			self.current_dialog = current_dialog.csel
			self.must_parent_close = True
		elif isinstance(current_dialog,MovieSelection):
			self.current_dialog = current_dialog
			self.must_parent_close = False
		self.parent = current_dialog
		self.title = _("Movie History Browser")
		self["actions"] = ActionMap(["WizardActions", "ColorActions", "MovieSelectionActions"],
		{
			"back": self.close_pressed,
			"red": self.close_pressed,
			"green": self.ok_pressed,
			"blue": self.clearall_pressed,
			"yellow": self.delete_pressed,
			"ok": self.ok_pressed,
			"contextMenu": self.contextMenu_pressed,
		}, -1)
		self["list"] = MerlinMovieHistoryList(eMerlin.getInstance().getMerlinMovieHistoryTupleList())
		self["key_red"] = StaticText(_("Close"))
		self["key_green"] = StaticText(_("OK"))
		self["key_yellow"] = StaticText(_("Delete entry"))
		self["key_blue"] = StaticText(_("Delete All"))

	def contextMenu_pressed(self):
		self.session.openWithCallback(self.merlinMovieHistorySetupCallback, MerlinMovieHistorySetup)
		
	def merlinMovieHistorySetupCallback(self):
		self["list"].setList(eMerlin.getInstance().getMerlinMovieHistoryTupleList())
	
	def close_pressed(self):
		self.close(None, self.current_dialog)	

	def clearall_pressed(self):
		eMerlin.getInstance().clearMovieHistory()
		self["list"].setList(eMerlin.getInstance().getMerlinMovieHistoryTupleList())

	def ok_pressed(self):
		cur = self["list"].current
		if cur:
			selection = eServiceReference(cur[0])
			dirname = os_path.dirname(selection.getPath()) + "/"
			do_reload = config.movielist.last_videodir.value != dirname
			if do_reload:
				config.movielist.last_videodir.value = dirname
				config.movielist.last_videodir.save()
				self.current_dialog.current_ref = eServiceReference("2:0:1:0:0:0:0:0:0:0:" + dirname)
				self.current_dialog["freeDiskSpace"].path = dirname
				self.current_dialog.reloadList(sel = selection, home = True)
			else:
				if not (self.current_dialog["list"].moveTo(selection)):
					self.current_dialog["list"].moveToIndex(0)	
			if self.must_parent_close:
				self.parent.close()
			self.close(selection, self.current_dialog)

	def delete_pressed(self):
		cur = self["list"].current
		if cur:
			if not eMerlin.getInstance().deleteMovieHistoryEntry(cur[0]):
				self["list"].setList(eMerlin.getInstance().getMerlinMovieHistoryTupleList())
