from Plugins.Plugin import PluginDescriptor
from Components.config import config, ConfigSubsection, ConfigYesNo, ConfigInteger
from enigma import eEnv
from merlin.emerlin import eMerlin
from MerlinMovieHistoryScreen import MerlinMovieHistoryScreen
from MerlinMovieHistorySetup import MerlinMovieHistorySetup

config.plugins.moviehistory = ConfigSubsection()
config.plugins.moviehistory.enabled = ConfigYesNo(default=True)
config.plugins.moviehistory.max = ConfigInteger(default=20, limits=(1, 99))
config.plugins.moviehistory.playmovie = ConfigYesNo(default=True)

def setMovieHistoryMax(configElement):
	eMerlin.getInstance().setMovieHistoryMax(config.plugins.moviehistory.max.value)

def enableMovieHistory(configElement):
	eMerlin.getInstance().enableMovieHistory(config.plugins.moviehistory.enabled.value)

config.plugins.moviehistory.max.addNotifier(setMovieHistoryMax, initial_call = False)
config.plugins.moviehistory.enabled.addNotifier(enableMovieHistory, initial_call = False)

def merlinMovieHistoryScreenCallback(service, dialog):
	if service is not None and config.plugins.moviehistory.playmovie.value:
		dialog.movieSelected()
	
def mainloop(reason, **kwargs):
	if reason == 0:
		eMerlin.getInstance().enableMovieHistory(config.plugins.moviehistory.enabled.value)
		
def movielist(session, service, **kwargs):
	session.openWithCallback(merlinMovieHistoryScreenCallback, MerlinMovieHistoryScreen, session.current_dialog)

def setup(session,**kwargs):
	session.open(MerlinMovieHistorySetup)

def Plugins(**kwargs):
	list = [PluginDescriptor(name=_("Movie History Browser Setup"), description=_("Movie History Browser Setup"), where = PluginDescriptor.WHERE_PLUGINMENU, fnc=setup, icon = "merlinmoviehostorybrowser.png")]
	list.append(PluginDescriptor(where = PluginDescriptor.WHERE_SESSIONSTART, fnc = mainloop))
	list.append(PluginDescriptor(where = PluginDescriptor.WHERE_SESSIONSTART, fnc = skin_loader))
	list.append(PluginDescriptor(name=_("History Browser"), description=_("History Browser..."), where = [PluginDescriptor.WHERE_MOVIELIST, PluginDescriptor.WHERE_MOVIELISTFOLDER], fnc = movielist, weight = -1))
	return list
	
def skin_loader(reason, **kwargs):
	if reason == 0:
		from skin import loadSkin, loadSingleSkinData, dom_skins
		from enigma import getDesktop
		from Tools.Directories import resolveFilename, SCOPE_CURRENT_PLUGIN
		skindir =  eEnv.resolve("${libdir}/enigma2/python/Plugins/Extensions/MerlinMovieHistoryBrowser/skins/")
		desktopSize = getDesktop(0).size().height()
		skinFile = resolveFilename(SCOPE_CURRENT_PLUGIN, skindir + "skin_%d.xml" % desktopSize)
		loadSkin(skinFile, "")
		path, dom_skin = dom_skins[-1:][0]
		loadSingleSkinData(getDesktop(0), dom_skin, path)
	



